@@ -149,6 +149,17 @@ class SecurityManagerApis():
             print("Exception occurred while updating rule doc for Device ID '{0}'\n Exception : {1}".
                   format(device_id, e.response.text))
 
+    def logout(self) -> list:
+        self.headers['Connection'] = 'Close'
+        pp_tkt_url = self.parser.get('REST', 'logout_api_url').format(self.host)
+        try:
+            resp = requests.post(url=pp_tkt_url, headers=self.headers, verify=self.verify_ssl)
+            return resp.status_code, resp.reason
+        except requests.exceptions.HTTPError as e:
+            print(
+                "Exception occurred while attempting to logout\n Exception : {0}".
+                    format(e.response.text))
+
     def bulk_add_supp_route(self, f) -> int:
         """
         Bulk adding Supplemental Routes via formatted text file
